Converts various inputs into a dribble. This is how every protondrive
function interprets its file and path arguments:
A dribble is returned as is.
A character vector is treated as paths and looked up with pd_get().
A character vector marked with as_id() is looked up by ID.
A data frame with the columns of a dribble is validated and converted.
Arguments
- x
An object to coerce.
- ...
Not used.
- call
The execution environment of a currently running function,
used in error messages.
Examples
if (FALSE) { # \dontrun{
as_dribble("reports/q3.csv")
as_dribble(as_id("vol...~node..."))
} # }