Copies a file or folder, possibly into a different folder. This is the
analogue of googledrive::drive_cp(). Unlike moving, copying works
between your files and folders shared with you by other people.
Arguments
- file
The file or folder to copy, as a path, an ID marked with
as_id(), or a one-row dribble.- path
Destination folder. Defaults to the folder
fileis in.- name
Name of the copy. Defaults to
"Copy of <name>"when copying within the same folder, and to the original name otherwise.- overwrite
What to do if something called
namealready exists inpath.FALSE(the default) is an error;TRUEmoves the existing item to the trash first.
Value
A one-row dribble for the copy, invisibly.