Downloads and decrypts a file or folder to your computer. This is the
analogue of googledrive::drive_download(). Proton Docs and Sheets
cannot be downloaded this way.
Value
A one-row dribble for the downloaded file, with an extra
local_path column, invisibly.
Examples
if (FALSE) { # \dontrun{
pd_download("data/mtcars.csv")
pd_download("data/mtcars.csv", path = tempfile(fileext = ".csv"))
pd_download("data", path = "local-copy-of-data")
} # }