Creates a new folder. This is the analogue of
googledrive::drive_mkdir().
Arguments
- name
Name of the new folder. It may include a path, such as
"reports/2026", in which casepathmust not be given and the parent (herereports) must already exist.- path
Parent folder, given as a path, an ID marked with
as_id(), or a one-row dribble. Defaults to/my-files.- overwrite
What to do if a file or folder called
namealready exists inpath. Proton Drive never allows two items with the same name in one folder, soFALSE(the default) is an error, whileTRUEmoves the existing item to the trash first.
Value
A one-row dribble for the new folder, invisibly.